summaryrefslogtreecommitdiff
path: root/TAO/examples/Callback_Quoter
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/examples/Callback_Quoter')
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_Handler.cpp30
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_Input_Handler.cpp14
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_Signal_Handler.cpp12
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_i.cpp4
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_i.h4
-rw-r--r--TAO/examples/Callback_Quoter/Notifier_Input_Handler.cpp24
-rw-r--r--TAO/examples/Callback_Quoter/Notifier_Input_Handler.h6
-rw-r--r--TAO/examples/Callback_Quoter/Notifier_i.cpp8
-rw-r--r--TAO/examples/Callback_Quoter/Notifier_i.h8
-rw-r--r--TAO/examples/Callback_Quoter/Supplier_i.cpp14
-rw-r--r--TAO/examples/Callback_Quoter/notifier.cpp6
11 files changed, 65 insertions, 65 deletions
diff --git a/TAO/examples/Callback_Quoter/Consumer_Handler.cpp b/TAO/examples/Callback_Quoter/Consumer_Handler.cpp
index 647b643db66..4aeab0b4941 100644
--- a/TAO/examples/Callback_Quoter/Consumer_Handler.cpp
+++ b/TAO/examples/Callback_Quoter/Consumer_Handler.cpp
@@ -161,7 +161,7 @@ Consumer_Handler::parse_args (void)
int
Consumer_Handler::via_naming_service (void)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// Initialization of the naming service.
@@ -177,14 +177,14 @@ Consumer_Handler::via_naming_service (void)
CORBA::Object_var notifier_obj =
this->naming_services_client_->resolve (notifier_ref_name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// The CORBA::Object_var object is downcast to Notifier_var using
// the <_narrow> method.
this->server_ =
Notifier::_narrow (notifier_obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
@@ -211,14 +211,14 @@ Consumer_Handler::init (int argc, char **argv)
// Register our <Input_Handler> to handle STDIN events, which will
// trigger the <handle_input> method to process these events.
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// Retrieve the ORB.
this->orb_ = CORBA::ORB_init (this->argc_,
this->argv_,
0
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
@@ -281,7 +281,7 @@ Consumer_Handler::init (int argc, char **argv)
CORBA::Object_var server_object =
this->orb_->string_to_object (this->ior_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (CORBA::is_nil (server_object.in ()))
@@ -292,7 +292,7 @@ Consumer_Handler::init (int argc, char **argv)
// The downcasting from CORBA::Object_var to Notifier_var is
// done using the <_narrow> method.
this->server_ = Notifier::_narrow (server_object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
@@ -312,23 +312,23 @@ int
Consumer_Handler::run (void)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// Obtain and activate the RootPOA.
CORBA::Object_var obj =
- this->orb_->resolve_initial_references ("RootPOA" TAO_ENV_ARG_PARAMETER);
+ this->orb_->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POA_var root_poa =
- PortableServer::POA::_narrow (obj.in () TAO_ENV_ARG_PARAMETER);
+ PortableServer::POA::_narrow (obj.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager=
- root_poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ root_poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_NEW_RETURN (this->consumer_servant_,
@@ -339,7 +339,7 @@ Consumer_Handler::run (void)
// Get the consumer stub (i.e consumer object) pointer.
this->consumer_var_ =
- this->consumer_servant_->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_servant_->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
if (this->interactive_ == 0)
@@ -349,7 +349,7 @@ Consumer_Handler::run (void)
this->server_->register_callback (this->stock_name_,
this->threshold_value_,
this->consumer_var_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Note the registration.
@@ -361,7 +361,7 @@ Consumer_Handler::run (void)
}
// Run the ORB.
- this->orb_->run (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->orb_->run (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
diff --git a/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.cpp b/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.cpp
index d78291ee729..5fe25a265f6 100644
--- a/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.cpp
+++ b/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.cpp
@@ -39,7 +39,7 @@ Consumer_Signal_Handler::handle_signal (int /* signum */,
" Exiting on receiving ^C\n"));
quit_on_signal ();
-
+
return 0;
}
@@ -66,13 +66,13 @@ Consumer_Signal_Handler::quit_on_signal (void)
{
if (consumer_handler_->unregistered_ != 1
&& consumer_handler_->registered_ == 1)
- {
- this->consumer_handler_->server_->unregister_callback
+ {
+ this->consumer_handler_->server_->unregister_callback
(this->consumer_handler_->consumer_var_.in ());
- ACE_DEBUG ((LM_DEBUG,
- "Consumer Unregistered\n"));
+ ACE_DEBUG ((LM_DEBUG,
+ "Consumer Unregistered\n"));
}
- this->consumer_handler_->consumer_servant_->shutdown (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_handler_->consumer_servant_->shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
diff --git a/TAO/examples/Callback_Quoter/Consumer_i.cpp b/TAO/examples/Callback_Quoter/Consumer_i.cpp
index 380ff65ecfe..b892a31372c 100644
--- a/TAO/examples/Callback_Quoter/Consumer_i.cpp
+++ b/TAO/examples/Callback_Quoter/Consumer_i.cpp
@@ -29,7 +29,7 @@ Consumer_i::~Consumer_i (void)
void
Consumer_i::push (const Callback_Quoter::Info &data
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
// On getting the needed information you now proceed to the next
@@ -42,7 +42,7 @@ Consumer_i::push (const Callback_Quoter::Info &data
}
void
-Consumer_i::shutdown (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+Consumer_i::shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
diff --git a/TAO/examples/Callback_Quoter/Consumer_i.h b/TAO/examples/Callback_Quoter/Consumer_i.h
index 3e7a28df332..839f2768c6a 100644
--- a/TAO/examples/Callback_Quoter/Consumer_i.h
+++ b/TAO/examples/Callback_Quoter/Consumer_i.h
@@ -40,11 +40,11 @@ public:
// Destructor.
void push (const Callback_Quoter::Info & data
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Gets the stock information from the Notifier.
- virtual void shutdown (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Used to get the consumer to shut down.
diff --git a/TAO/examples/Callback_Quoter/Notifier_Input_Handler.cpp b/TAO/examples/Callback_Quoter/Notifier_Input_Handler.cpp
index b117ea3d1ab..edaff2abfee 100644
--- a/TAO/examples/Callback_Quoter/Notifier_Input_Handler.cpp
+++ b/TAO/examples/Callback_Quoter/Notifier_Input_Handler.cpp
@@ -52,7 +52,7 @@ Notifier_Input_Handler::~Notifier_Input_Handler (void)
// the object name is bound to the naming server.
int
-Notifier_Input_Handler::init_naming_service (TAO_ENV_SINGLE_ARG_DECL)
+Notifier_Input_Handler::init_naming_service (ACE_ENV_SINGLE_ARG_DECL)
{
CORBA::ORB_var orb = this->orb_manager_.orb ();
@@ -69,15 +69,15 @@ Notifier_Input_Handler::init_naming_service (TAO_ENV_SINGLE_ARG_DECL)
// (re)Bind the object.
ACE_TRY
{
- Notifier_var notifier_obj = notifier_i_._this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ Notifier_var notifier_obj = notifier_i_._this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- this->orb_manager_.activate_poa_manager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->orb_manager_.activate_poa_manager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
naming_server_->rebind (notifier_obj_name,
notifier_obj.in()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
@@ -142,7 +142,7 @@ Notifier_Input_Handler::parse_args (void)
int
Notifier_Input_Handler::init (int argc,
char *argv[]
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
// Call the init of <TAO_ORB_Manager> to initialize the ORB and
@@ -154,7 +154,7 @@ Notifier_Input_Handler::init (int argc,
if (this->orb_manager_.init_child_poa (this->argc_,
this->argv_,
"child_poa"
- TAO_ENV_ARG_PARAMETER) == -1)
+ ACE_ENV_ARG_PARAMETER) == -1)
ACE_ERROR_RETURN ((LM_ERROR,
"%p\n",
"init_child_poa"),
@@ -187,7 +187,7 @@ Notifier_Input_Handler::init (int argc,
CORBA::String_var str =
this->orb_manager_.activate_under_child_poa ("Notifier",
&this->notifier_i_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
ACE_DEBUG ((LM_DEBUG,
@@ -204,14 +204,14 @@ Notifier_Input_Handler::init (int argc,
if (this->using_naming_service_)
{
- this->init_naming_service (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->init_naming_service (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
}
return 0;
}
int
-Notifier_Input_Handler::run (TAO_ENV_SINGLE_ARG_DECL)
+Notifier_Input_Handler::run (ACE_ENV_SINGLE_ARG_DECL)
{
// Run the main event loop for the ORB.
@@ -219,7 +219,7 @@ Notifier_Input_Handler::run (TAO_ENV_SINGLE_ARG_DECL)
ACE_DEBUG ((LM_DEBUG,
" Type \"q\" to quit \n "));
- int result = this->orb_manager_.run (TAO_ENV_SINGLE_ARG_PARAMETER);
+ int result = this->orb_manager_.run (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK_RETURN (-1);
if (result == -1)
@@ -237,7 +237,7 @@ Notifier_Input_Handler::handle_input (ACE_HANDLE)
{
char buf[BUFSIZ];
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
@@ -259,7 +259,7 @@ Notifier_Input_Handler::handle_input (ACE_HANDLE)
{
// @@ Please remove this call if it's not used.
// (this->notifier_i_.consumer_map_).close();
- this->notifier_i_.shutdown (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->notifier_i_.shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
}
diff --git a/TAO/examples/Callback_Quoter/Notifier_Input_Handler.h b/TAO/examples/Callback_Quoter/Notifier_Input_Handler.h
index 4012a86e4a1..f9b1a091ed6 100644
--- a/TAO/examples/Callback_Quoter/Notifier_Input_Handler.h
+++ b/TAO/examples/Callback_Quoter/Notifier_Input_Handler.h
@@ -45,10 +45,10 @@ public:
int init (int argc,
char *argv[]
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Initialize the Notifier who plays the role of the server here.
- int run (TAO_ENV_SINGLE_ARG_DECL);
+ int run (ACE_ENV_SINGLE_ARG_DECL);
// Run the ORB.
virtual int handle_input (ACE_HANDLE);
@@ -62,7 +62,7 @@ private:
int parse_args (void);
// Parses the command line arguments.
- int init_naming_service (TAO_ENV_SINGLE_ARG_DECL);
+ int init_naming_service (ACE_ENV_SINGLE_ARG_DECL);
// Initialises the name server and registers the Notifier object
// name with the name server.
diff --git a/TAO/examples/Callback_Quoter/Notifier_i.cpp b/TAO/examples/Callback_Quoter/Notifier_i.cpp
index 470f4bf315b..632820180a4 100644
--- a/TAO/examples/Callback_Quoter/Notifier_i.cpp
+++ b/TAO/examples/Callback_Quoter/Notifier_i.cpp
@@ -38,7 +38,7 @@ void
Notifier_i::register_callback (const char *stock_name,
CORBA::Long threshold_value,
Callback_Quoter::Consumer_ptr consumer_handler
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
Callback_Quoter::Invalid_Stock))
{
@@ -107,7 +107,7 @@ Notifier_i::orb (CORBA::ORB_ptr orb)
void
Notifier_i::unregister_callback (Callback_Quoter::Consumer_ptr consumer
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
Callback_Quoter::Invalid_Handle))
{
@@ -154,7 +154,7 @@ Notifier_i::unregister_callback (Callback_Quoter::Consumer_ptr consumer
void
Notifier_i::market_status (const char *stock_name,
CORBA::Long stock_value
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
ACE_DEBUG ((LM_DEBUG,
@@ -202,7 +202,7 @@ Notifier_i::market_status (const char *stock_name,
}
void
-Notifier_i::shutdown (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+Notifier_i::shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
if ( this->consumer_map_.close () > 0)
diff --git a/TAO/examples/Callback_Quoter/Notifier_i.h b/TAO/examples/Callback_Quoter/Notifier_i.h
index d3d326e3e58..9c99934879e 100644
--- a/TAO/examples/Callback_Quoter/Notifier_i.h
+++ b/TAO/examples/Callback_Quoter/Notifier_i.h
@@ -52,28 +52,28 @@ public:
virtual void register_callback (const char *stock_name,
CORBA::Long threshold_value,
Callback_Quoter::Consumer_ptr consumer_handler
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
Callback_Quoter::Invalid_Stock));
// Register a distributed callback handler that is invoked when the
// given stock reaches the desired threshold value.
virtual void unregister_callback (Callback_Quoter::Consumer_ptr consumer_handler
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException,
Callback_Quoter::Invalid_Handle));
// Remove the consumer object.
virtual void market_status (const char *stock_name,
CORBA::Long stock_value
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Get the market status.
void orb (CORBA::ORB_ptr orb);
// Get the orb pointer.
- virtual void shutdown (TAO_ENV_SINGLE_ARG_DECL)
+ virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
// Shutdown the Notifier.
diff --git a/TAO/examples/Callback_Quoter/Supplier_i.cpp b/TAO/examples/Callback_Quoter/Supplier_i.cpp
index a01dec538d8..b3b3072d046 100644
--- a/TAO/examples/Callback_Quoter/Supplier_i.cpp
+++ b/TAO/examples/Callback_Quoter/Supplier_i.cpp
@@ -153,7 +153,7 @@ int
Supplier::send_market_status (const char *stock_name,
long value)
{
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
@@ -161,7 +161,7 @@ Supplier::send_market_status (const char *stock_name,
// Make the RMI.
this->notifier_->market_status (stock_name,
value
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCH (CORBA::SystemException, sysex)
@@ -229,14 +229,14 @@ Supplier::via_naming_service (void)
CORBA::Object_var notifier_obj =
this->naming_services_client_->resolve (notifier_ref_name
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// The CORBA::Object_var object is downcast to Notifier_var
// using the <_narrow> method.
this->notifier_ =
Notifier::_narrow (notifier_obj.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCH (CORBA::SystemException, sysex)
@@ -270,7 +270,7 @@ Supplier::init (int argc, char **argv)
this->orb_ = CORBA::ORB_init (this->argc_,
this->argv_,
0
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Parse command line and verify parameters.
@@ -294,7 +294,7 @@ Supplier::init (int argc, char **argv)
-1);
CORBA::Object_var notifier_object =
this->orb_->string_to_object (this->ior_
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (CORBA::is_nil (notifier_object.in ()))
@@ -305,7 +305,7 @@ Supplier::init (int argc, char **argv)
// The downcasting from CORBA::Object_var to Notifier_var is
// done using the <_narrow> method.
this->notifier_ = Notifier::_narrow (notifier_object.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCH (CORBA::SystemException, sysex)
diff --git a/TAO/examples/Callback_Quoter/notifier.cpp b/TAO/examples/Callback_Quoter/notifier.cpp
index 246f16e2ccd..44f07d70cd1 100644
--- a/TAO/examples/Callback_Quoter/notifier.cpp
+++ b/TAO/examples/Callback_Quoter/notifier.cpp
@@ -14,17 +14,17 @@ main (int argc, char *argv[])
ACE_DEBUG ((LM_DEBUG,
"\n\tNotifier\n\n"));
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
- int rc = notifier.init (argc, argv TAO_ENV_ARG_PARAMETER);
+ int rc = notifier.init (argc, argv ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (rc == -1)
return 1;
else
{
- notifier.run (TAO_ENV_SINGLE_ARG_PARAMETER);
+ notifier.run (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
}
diff --git a/TAO/examples/Callback_Quoter/Consumer_Input_Handler.cpp b/TAO/examples/Callback_Quoter/Consumer_Input_Handler.cpp
index c98a8522314..a06a4267cf3 100644
--- a/TAO/examples/Callback_Quoter/Consumer_Input_Handler.cpp
+++ b/TAO/examples/Callback_Quoter/Consumer_Input_Handler.cpp
@@ -102,7 +102,7 @@ Consumer_Input_Handler::register_consumer ()
this->consumer_handler_->threshold_value_ =
ACE_OS::atoi (needed_stock_value);
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
@@ -111,7 +111,7 @@ Consumer_Input_Handler::register_consumer ()
this->consumer_handler_->server_->register_callback (this->consumer_handler_->stock_name_,
this->consumer_handler_->threshold_value_,
this->consumer_handler_->consumer_var_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Note the registration.
@@ -165,7 +165,7 @@ Consumer_Input_Handler::quit_consumer_process ()
// Only if the consumer is registered and wants to shut
// down, its necessary to unregister and then shutdown.
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
@@ -173,9 +173,9 @@ Consumer_Input_Handler::quit_consumer_process ()
{
// If the notifier has exited and the consumer tries to call
// the unregister_callback method tehn an execption will be
// raised. Hence check for this case using TAO_ENV_SINGLE_ARG_PARAMETER.
this->consumer_handler_->server_->unregister_callback (this->consumer_handler_->consumer_var_.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
ACE_DEBUG ((LM_DEBUG,
@@ -183,7 +183,7 @@ Consumer_Input_Handler::quit_consumer_process ()
consumer_handler_->unregistered_ = 0;
consumer_handler_->registered_ = 0;
}
- this->consumer_handler_->consumer_servant_->shutdown (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_handler_->consumer_servant_->shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -196,7 +196,7 @@ Consumer_Input_Handler::quit_consumer_process ()
ACE_TRY_EX (block1)
{
- this->consumer_handler_->consumer_servant_->shutdown (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->consumer_handler_->consumer_servant_->shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK_EX (block1);
}
ACE_CATCHANY
@@ -173,9 +173,9 @@ Consumer_Input_Handler::quit_consumer_process ()
// If the notifier has exited and the consumer tries to call
// the unregister_callback method tehn an execption will be
- // raised. Hence check for this case using TAO_ENV_SINGLE_ARG_PARAMETER.
+ // raised. Hence check for this case using ACE_ENV_SINGLE_ARG_PARAMETER.
this->consumer_handler_->server_->unregister_callback (this->consumer_handler_->consumer_var_.in ()